@@ -146,14 +146,22 @@ def read_file(file_path, create:bool=False, ret_did_create:bool=False, remove_em
     return lines
 
 
-def write_file(text, file_path, append=False, create=True, encoding='utf-8', do_print=True) -> bool:
+def write_file(text:Any, file_path:str, append:bool=False, create:bool=True, encoding:str='utf-8', do_print:bool=True) -> bool:
+    if text.__class__.__name__ == 'ndarray':
+        text = text.tolist()
+    
     if text.__class__.__name__ in ('list', 'tuple', 'set'):
         text = '\n'.join(text)
 
-    lines, did_create = read_file(file_path, create=True, ret_did_create=True, remove_empty=False, do_splitlines=False, do_print=do_print)
+    lines, did_create = read_file(file_path, create:=create, ret_did_create=True, remove_empty=False, splitlines=False, do_print=do_print)
 
-    if not did_create and lines[-1] != '\n':
-        text = '\n' + text 
+    try:
+        if not did_create and lines[-1] != '\n':
+            text = '\n' + text 
+    except IndexError:
+        pass
+    except Exception:
+        print(traceback.format_exc())
 
     if append:
         mode = 'a'
@@ -166,7 +174,7 @@ def write_file(text, file_path, append=False, create=True, encoding='utf-8', do_
     return did_create
 
 
-def create_file_dir(do, do_path, force=False, do_print=True) -> bool:
+def create_file_dir(do:str, do_path:str, force:bool=False, do_print:bool=True) -> bool:
     def create_dir():
         try:
             mkdir(do_path)
@@ -266,6 +274,10 @@ def join_path(*args, join_with='\\'):
     return join_with.join(args)
 
 
+def chunker(seq, size:int):
+    return (seq[pos:pos + size] for pos in range(0, len(seq), size))
+
+
 def create_json(filepath:str, force:bool=False, do_print:bool=True) -> bool:
     did_create = create_file_dir('f', filepath, force=force, do_print=do_print)
     if did_create:
@@ -273,7 +285,7 @@ def create_json(filepath:str, force:bool=False, do_print:bool=True) -> bool:
     return did_create
 
 
-def read_json(filepath:str):
+def read_json(filepath:str) -> Any:
     try:
         with open(filepath, 'r') as f:
             file_data = json.load(f)
@@ -282,5 +294,26 @@ def read_json(filepath:str):
         fprint(f'File not found: {filepath}')
     except json.decoder.JSONDecodeError:
         fprint(f'File cannot be read as a JSON: {filepath}')
+    except Exception:
+        fprint(traceback.format_exc())
+
+
+def write_json(data:Any, filepath:str, indent:int=4, force:bool=False, do_print:bool=True):
+    try:
+        if data.__class__.__name__ == ('str'):
+            data = json.loads(data)
+
+        d = read_json(filepath)
+        
+        if d and not force:
+            fprint(f'Data found in JSON file, not writing new data: {filepath}', do_print=do_print)
+            return
+
+        with open(filepath, 'w') as f:
+            json.dump(data, f, indent=indent)
+
+        fprint(f'Wrote data to JSON file: {filepath}', do_print=do_print)
+    except TypeError:
+        fprint(f'Data type is wrong, can\'t write to JSON: {data.__class__.__name__}', do_print=do_print)
     except Exception:
         fprint(traceback.format_exc())
\ No newline at end of file
